//
//  ViewController.m
//  QQWalletSDKDemo
//
//  Created by Eric on 17/9/1.
//  Copyright (c) 2017年 Teccent. All rights reserved.
//

#import "ViewController.h"
#import <CommonCrypto/CommonHMAC.h>
#import "QQWalletSDK.h"

@implementation ViewController

//
// 以下“签名”的步骤为了安全起见，应当放在后台处理
// 客户端从后台来获取签名后的字符串
//

// 将data用hmac-sha1算法加密
- (NSData *)hmacSha1:(NSData *)data key:(NSData *)key {
    NSMutableData *hmac = [NSMutableData dataWithLength:CC_SHA1_DIGEST_LENGTH];
    CCHmac( kCCHmacAlgSHA1, key.bytes, key.length, data.bytes, data.length, hmac.mutableBytes);
    return hmac;
}

// 生成签名串
- (NSString *)getMySignatureWithAppId:(NSString *)appId
                          bargainorId:(NSString *)bargainorId
                                nonce:(NSString *)nonce
                               pubAcc:(NSString *)pubAcc
                              tokenId:(NSString *)tokenId
                           signingKey:(NSString *)signingKey{
    
    // 1. 将 appId,bargainorId,nonce,tokenId 拼成字符串
    NSString *source = [NSString stringWithFormat:@"%@=%@&%@=%@&%@=%@&%@=%@&%@=%@",
                        QQWalletAppID, appId, QQWalletBargainorId, bargainorId, QQWalletNonce, nonce, QQWalletPubAcc, pubAcc, QQWalletTokenId, tokenId];
    
    // 2. 将刚才拼好的字符串，用key来加密
    // 【注意！】： 约定在key末尾拼一个‘&’符号
    NSData *signature = [source dataUsingEncoding:NSUTF8StringEncoding];
    NSData *signingData = [[signingKey stringByAppendingString:@"&"] dataUsingEncoding:NSUTF8StringEncoding];
    NSData *digest = [self hmacSha1:signature key:signingData];
    
    // 3. 将加密后的data以base64形式输出
    NSString *signatureBase64 = [digest base64Encoding];
    return signatureBase64;
}

// 获取一个随机串
- (NSString *)getNonce{
    NSString *nonce = [NSString stringWithFormat:@"%x%x",arc4random(),arc4random()];
    return nonce;
}

// 获取一个demo订单号
- (NSString *)getTokenIDForThisDemo{
    NSURL* url = [NSURL URLWithString:@"http://iv.qq.com/wallet/monitor/cgi/token"];  // demo
    NSURLRequest* request = [NSURLRequest requestWithURL:url];
    NSError* error = nil;
    NSData* data = [NSURLConnection sendSynchronousRequest:request returningResponse:nil error:&error];
    if (!error) {
        NSDictionary* infos = [NSJSONSerialization JSONObjectWithData:data options:NSJSONReadingMutableLeaves error:&error];
        if (!error) {
            NSString* tokenId = infos[@"token"]; // 取得订单号
            return tokenId;
        }
    }
    return nil;
}


// ****************************************************************************
// 支付调用
//  注意：请在info.plist加入：
//    <key>LSApplicationQueriesSchemes</key>
//    <array>
//    <string>mqqwallet</string>
//    </array>
//  否则在iOS9及以上会出现报错： -canOpenURL: failed for URL: "mqqwallet://" - error: "This app is not allowed to query for scheme mqqwallet"
- (IBAction) pay:(id)sender{
    NSString *appId = @"100619284";                             // 第三方APP在QQ钱包开放平台申请的appID
    NSString *appKey = @"d139ae6fb0175e5659dce2a7c1fe84d5";     // appID对应的appKey (这个key应当保存在后台，在后台进行签名)
    NSString *bargainorId = @"2001";                            // 第三方APP在财付通后台的商户号
    NSString *tokenId = [self getTokenIDForThisDemo];           // 本demo的订单号
    NSString *nonce = [self getNonce];                          // 随机串
    NSString *pubAcc = @"";                                     // 公众号，没有就填空 @""
    NSString *scheme = @"qqwalletdemoscheme";                   // APP的URL SCHEME，用户在手机QQ内部完成功能后进行回调.在您的工程中的plist文件中创建用于回调的URL SCHEMA。此URL SCHEMA用于手机QQ完成功能后，传递结果信息用。请尽量保证此URL SCHEMA不会与其他冲突。
    
    // 获取签名串
    NSString *sig = [self getMySignatureWithAppId:appId
                                      bargainorId:bargainorId
                                            nonce:nonce
                                           pubAcc:pubAcc
                                          tokenId:tokenId
                                       signingKey:appKey];
    
    // 发起支付
    [[QQWalletSDK sharedInstance] startPayWithAppId:appId
                                        bargainorId:bargainorId
                                            tokenId:tokenId
                                          signature:sig
                                              nonce:nonce
                                             scheme:scheme
                                         completion:^(QQWalletErrCode errCode, NSString *errStr){
                                             // 支付完成的回调处理
                                             if (errCode == QQWalletErrCodeSuccess) {
                                                 // 对支付成功的处理
                                                 self.textLabel.text = errStr;
                                             }else{
                                                 // 对支付失败的处理
                                                 self.textLabel.text = errStr;
                                             }
                                         }];
}


@end
